@@ -23,7 +23,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.43.2.2 2005/04/14 17:23:06 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.47 2005/04/19 11:30:18 chpe Exp $
  */
 
 #include "config.h"
@@ -217,12 +217,11 @@ EphyDialogProperty properties [] =
 	{ NULL }
 };
 
-static GtkTargetEntry drag_targets[] =
+static const GtkTargetEntry drag_targets[] =
 {
-	{ EPHY_DND_URL_TYPE,	  0, 0 }//,
-	//{ EPHY_DND_URI_LIST_TYPE, 0, 1}
+	{ EPHY_DND_URL_TYPE,	  0, 0 }
+	/* { EPHY_DND_URI_LIST_TYPE, 0, 1} */
 };
-static int n_drag_targets = G_N_ELEMENTS (drag_targets);
 
 static void page_info_dialog_class_init	(PageInfoDialogClass *klass);
 static void page_info_dialog_init	(PageInfoDialog *dialog);
@@ -457,7 +456,7 @@ struct _TreeviewInfoPage
 	GtkTreeSelection *selection;
 	GtkTreeView *treeview;
 	TreeviewInfoPageFilterFunc filter_func;
-	GtkActionEntry *action_entries;
+	const GtkActionEntry *action_entries;
 	guint n_action_entries;
 	const char *popup_path;
 	const char *copy_action;
@@ -543,7 +542,7 @@ treeview_info_page_filter (TreeviewInfoPage *page)
 	g_return_if_fail (action != NULL);
 
 	count = gtk_tree_selection_count_selected_rows (selection);
-	g_object_set (G_OBJECT (action), "sensitive", count == 1, NULL);
+	gtk_action_set_sensitive (action, count == 1);
 }
 
 static gboolean
@@ -1048,7 +1047,7 @@ media_set_image_as_background_cb (GtkAction *action,
 	g_free (base_converted);
 }
 
-static GtkActionEntry media_action_entries[] =
+static const GtkActionEntry media_action_entries[] =
 {
 	{ "Open",
 	  GTK_STOCK_OPEN,
@@ -1167,10 +1166,10 @@ media_info_page_filter (TreeviewInfoPage *page)
 	}
 	action = gtk_action_group_get_action (dialog->priv->action_group,
 					      "CopyMediumAddress");
-	g_object_set (action, "visible", one_col, NULL);
+	gtk_action_set_visible (action, one_col);
 	action = gtk_action_group_get_action (dialog->priv->action_group,
 					      "SetAsBackground");
-	g_object_set (action, "visible", one_col && can_set_as_background, NULL);
+	gtk_action_set_visible (action, one_col && can_set_as_background);
 }
 
 static void
@@ -1224,7 +1223,7 @@ media_info_page_construct (InfoPage *ipage)
 
 	/* Allow the tree to be a source for dnd */
 	gtk_tree_view_enable_model_drag_source (treeview, GDK_BUTTON1_MASK,
-                                                drag_targets, n_drag_targets,
+                                                drag_targets, G_N_ELEMENTS (drag_targets),
                                                 GDK_ACTION_COPY);
 	g_signal_connect (G_OBJECT(treeview),
                           "drag_data_get",
@@ -1338,7 +1337,7 @@ media_info_page_construct (InfoPage *ipage)
 	/* FIXME: implement "Open", then remove this */
 	action = gtk_action_group_get_action (dialog->priv->action_group,
 					      "Open");
-	g_object_set (action, "visible", FALSE, NULL);
+	gtk_action_set_sensitive (action, FALSE);
 }
 
 static void
@@ -1406,7 +1405,7 @@ enum
 	COL_LINK_REL
 };
 
-static GtkActionEntry links_action_entries[] =
+static const GtkActionEntry links_action_entries[] =
 {
 	{ "CopyLinkAddress", 
 	  GTK_STOCK_COPY,
@@ -1466,7 +1465,7 @@ links_info_page_construct (InfoPage *ipage)
 
 	/* Allow the tree to be a source for dnd */
 	gtk_tree_view_enable_model_drag_source (treeview, GDK_BUTTON1_MASK,
-                                                drag_targets, n_drag_targets,
+                                                drag_targets, G_N_ELEMENTS (drag_targets),
                                                 GDK_ACTION_COPY);
 	g_signal_connect (G_OBJECT(treeview),
                           "drag_data_get",
@@ -1585,7 +1584,7 @@ enum
 };
 
 /*
-static GtkActionEntry forms_action_entries[] =
+static const GtkActionEntry forms_action_entries[] =
 {
 };
 */
@@ -1717,7 +1716,7 @@ enum
 	COL_META_CONTENT
 };
 
-static GtkActionEntry metadata_action_entries[] =
+static const GtkActionEntry metadata_action_entries[] =
 {
 	{ "CopyMetadata", 
 	  GTK_STOCK_COPY,
