@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.11 2005/01/13 23:12:39 chpe Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.14 2005/04/19 11:30:19 chpe Exp $
  */
 
 #include "config.h"
@@ -233,7 +233,8 @@ context_menu_cb (EphyEmbed *embed,
 	action = gtk_action_group_get_action (data->action_group, LOOKUP_ACTION);
 	g_return_val_if_fail (action != NULL, FALSE);
 
-	g_object_set(action, "sensitive", can_copy, "visible", can_copy, NULL);
+	gtk_action_set_sensitive (action, can_copy);
+	gtk_action_set_visible (action, can_copy);
 
 	return FALSE;
 }
@@ -285,7 +286,7 @@ rebuild_ui (WindowData *data)
 	char verb[SMB_ACTION_LENGTH];
 	int i;
 
-	LOG ("Rebuilding UI")
+	LOG ("Rebuilding UI");
 
 	/* clean UI */
 	if (data->ui_id != 0)
@@ -492,7 +493,7 @@ smart_bookmark_added_cb (EphyNode *keywords,
 			 EphyNode *bmk,
 			 SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks added")
+	LOG ("SmartBookmarksExtension smart bookmarks added");
 
 	foreach_window ((GFunc) add_bookmark_to_window, bmk);
 }
@@ -503,7 +504,7 @@ smart_bookmark_removed_cb (EphyNode *keywords,
 			   guint old_index,
 			   SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks removed")
+	LOG ("SmartBookmarksExtension smart bookmarks removed");
 
 	foreach_window ((GFunc) remove_bookmark_from_window, bmk);
 }
@@ -514,7 +515,7 @@ smart_bookmark_changed_cb (EphyNode *node,
 			   guint property_id,
 			   SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks changed")
+	LOG ("SmartBookmarksExtension smart bookmarks changed");
 
 	if (property_id == EPHY_NODE_BMK_PROP_TITLE)
 	{
@@ -571,7 +572,7 @@ connect_proxy_cb (GtkActionGroup *action_group,
 	}
 }
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ LOOKUP_ACTION,
 	  NULL,
@@ -600,7 +601,7 @@ impl_attach_window (EphyExtension *ext,
 	EphyNode *smart_bmks, *bmk;
 	int i;
 
-	LOG ("SmartBookmarksExtension attach_window %p", window)
+	LOG ("SmartBookmarksExtension attach_window %p", window);
 
 	/* Attach ui infos to the window */
 	data = g_new0 (WindowData, 1);
@@ -643,7 +644,7 @@ impl_detach_window (EphyExtension *ext,
 {
 	WindowData *data;
 
-	LOG ("SmartBookmarksExtension detach_window")
+	LOG ("SmartBookmarksExtension detach_window");
 
 	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 	g_return_if_fail (data != NULL);
@@ -670,7 +671,7 @@ smart_bookmarks_extension_init (SmartBookmarksExtension *extension)
 	EphyBookmarks *bookmarks;
 	EphyNode *smart_bmks;
 
-	LOG ("SmartBookmarksExtension initialising")
+	LOG ("SmartBookmarksExtension initialising");
 
 	extension->priv = SMART_BOOKMARKS_EXTENSION_GET_PRIVATE (extension);
 
